@@ -1,6 +1,5 @@
 """Fundamental Analysis Controller."""
 __docformat__ = "numpy"
-
 import argparse
 import logging
 from datetime import datetime, timedelta
@@ -32,6 +31,7 @@ from openbb_terminal.stocks.fundamental_analysis import (
     polygon_view,
     fmp_view,
     eodhd_view,
+    seeking_alpha_view,
 )
 
 # pylint: disable=inconsistent-return-statements,C0302,R0904
@@ -53,6 +53,8 @@ class FundamentalAnalysisController(StockBaseController):
         "metrics",
         "ratios",
         "growth",
+        "revfc",
+        "epsfc",
         "warnings",
         "data",
         "income",
@@ -107,7 +109,6 @@ class FundamentalAnalysisController(StockBaseController):
 
         if session and obbff.USE_PROMPT_TOOLKIT:
             choices: dict = self.choices_default
-
             self.completer = NestedCompleter.from_nested_dict(choices)
 
     def print_help(self):
@@ -130,6 +131,8 @@ class FundamentalAnalysisController(StockBaseController):
         mt.add_cmd("metrics")
         mt.add_cmd("ratios")
         mt.add_cmd("growth")
+        mt.add_cmd("revfc")
+        mt.add_cmd("epsfc")
         mt.add_cmd("warnings")
         mt.add_cmd("dcf")
         mt.add_cmd("dcfc")
@@ -543,6 +546,34 @@ class FundamentalAnalysisController(StockBaseController):
                 self.ticker, start_date=ns_parser.start, export=ns_parser.export
             )
 
+    @log_start_end(log=logger)
+    def call_epsfc(self, other_args: List[str]):
+        """Process eps forecast command."""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="epsfc",
+            description="""Estimated EPS [Source: Seeking Alpha]""",
+        )
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+
+        if ns_parser:
+            seeking_alpha_view.display_eps_estimates(self.ticker)
+
+    @log_start_end(log=logger)
+    def call_revfc(self, other_args: List[str]):
+        """Process revenue forecast command."""
+        parser = argparse.ArgumentParser(
+            add_help=False,
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            prog="revfc",
+            description="""Estimated revenue [Source: Seeking Alpha]""",
+        )
+        ns_parser = self.parse_known_args_and_warn(parser, other_args)
+
+        if ns_parser:
+            seeking_alpha_view.display_rev_estimates(self.ticker)
+
     @log_start_end(log=logger)
     def call_splits(self, other_args: List[str]):
         """Process splits command."""
